<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Αρχειοθέτης LXQt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>Ένας απλός και αγνώστου γραφικού περιβάλλοντος αρχειοθέτης σε Qt</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>Συγγραφείς</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Προγραμματισμός:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Ο Αρχειοθέτης LXQt προέρχεται από τα παρακάτω προγράμματα:
* Engrampa του γραφικού περιβάλλοντος MATE
* File Roller του γραφικού περιβάλλοντος Gnome
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>Άδεια χρήσης</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>Αρχειοθέτης LXQt

Πνευματικά δικαιώματα (C)  - 2020 η ομάδα LXQt

Αυτό το πρόγραμμα είναι ένα ελεύθερο λογισμικό· επιτρέπεται
η αναδιανομή ή/και η τροποποίησή του υπό τους όρους της άδειας
GNU Γενική Άδεια Χρήσης όπως έχουν δημοσιευθεί από το
«Free Software Foundation», είτε την έκδοση 2 αυτής της άδειας
ή (σύμφωνα με την επιλογή σας) οποιαδήποτε μεταγενέστερη έκδοση.

Αυτό το πρόγραμμα διανέμεται με την ελπίδα πως θα είναι χρήσιμο,
αλλά ΧΩΡΙΣ ΚΑΜΙΑ ΕΓΓΥΗΣΗ, χωρίς ακόμη και την υπονοούμενη εγγύηση
ΕΜΠΟΡΕΥΣΙΜΟΤΗΤΑΣ ή ΚΑΤΑΛΛΗΛΟΤΗΤΑΣ ΓΙΑ ΣΥΓΚΕΚΡΙΜΕΝΟ ΣΚΟΠΟ.
Δείτε την GNU Γενική Άδεια Χρήσης για περισσότερες λεπτομέρειες.

Θα πρέπει να έχετε παραλάβει ένα αντίγραφο της GNU Γενικής Άδειας Χρήσης
μαζί με αυτό το πρόγραμμα. Αν όχι, γράψτε στο Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Ο τύπος αρχειοθήκης δεν υποστηρίζεται.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 αρχεία (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Όλες οι υποστηριζόμενες μορφές</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Αποτυχία εκτέλεσης της εντολής.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Δεν βρέθηκε η εντολή.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>Η εντολή τερματίστηκε κανονικά.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Απαιτείται κωδικός πρόσβασης.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Ελλείπων τόμος.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Ακατάλληλο σύνολο χαρακτήρων.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Μη υποστηριζόμενη μορφή αρχείου.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Παρουσιάστηκαν άγνωστα σφάλματα.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Διαχωρισμός σε τόμους των</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Κωδικός πρόσβασης:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Κρυπτογράφηση και του κατάστιχου αρχείων</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Όλα τα αρχεία (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Εξαγωγή</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>Ε&amp;ξαγωγή όλων των αρχείων</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Εξ&amp;αγωγή των επιλεγμένων αρχείων</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Ενέργειες</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Αναδημιουργία των φακέλων</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>Αντικατάσταση των υπαρχόντων αρχείων</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>Να μην εξαχθούν τα παλαιότερα αρχεία</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="12"/>
        <source>All files (*)</source>
        <translation>Όλα τα αρχεία (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>File Archiver</source>
        <translation>Αρχειοθέτης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>Φιλτράρισμα αρχείων...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>&amp;File</source>
        <translation>&amp;Αρχείο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>&amp;View</source>
        <translation>&amp;Προβολή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>&amp;Icon Size</source>
        <translation>Μέγεθος της &amp;εικόνας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Main Toolbar</source>
        <translation>Κύρια εργαλειοθήκη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&amp;New</source>
        <translation>&amp;Νέο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>&amp;Open</source>
        <translation>Ά&amp;νοιγμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>Save &amp;As</source>
        <translation>Αποθήκευση &amp;ως</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>&amp;Extract</source>
        <translation>&amp;Εξαγωγή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>&amp;Test</source>
        <translation>&amp;Δοκιμή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <source>&amp;Properties</source>
        <translation>&amp;Ιδιότητες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="252"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Cu&amp;t</source>
        <translation>Α&amp;ποκοπή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>&amp;Copy</source>
        <translation>&amp;Αντιγραφή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <source>&amp;Paste</source>
        <translation>Επι&amp;κόλληση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Rename</source>
        <translation>&amp;Μετονομασία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="304"/>
        <source>&amp;Delete</source>
        <translation>&amp;Διαγραφή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>&amp;Select All</source>
        <translation>&amp;Επιλογή όλων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>&amp;Find</source>
        <translation>&amp;Αναζήτηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <location filename="../mainwindow.ui" line="439"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="335"/>
        <source>&amp;Add Files</source>
        <translation>&amp;Προσθήκη αρχείων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Add F&amp;older</source>
        <translation>Προσθήκη &amp;φακέλου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Pass&amp;word</source>
        <translation>Κωδικός &amp;πρόσβασης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="360"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Γραμμή εργαλείων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Γραμμή κατάστασης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;Δέντρο καταλόγων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>S&amp;how as Folder</source>
        <translation>Προβολή ως &amp;φάκελος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Show &amp;All Files</source>
        <translation>Εμφάνιση ό&amp;λων των αρχείων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>St&amp;op</source>
        <translation>&amp;Διακοπή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Esc</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>&amp;Reload</source>
        <translation>&amp;Επαναφόρτωση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Filename &amp;Encoding</source>
        <translation>&amp;Κωδικοποίηση του ονόματος αρχείου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>&amp;View Selected Items</source>
        <translation>&amp;Προβολή των επιλεγμένων αντικειμένων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>&amp;Filter</source>
        <translation>&amp;Φίλτρο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>&amp;Expand</source>
        <translation>&amp;Ανάπτυξη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Κάτω</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>&amp;Collapse</source>
        <translation>&amp;Σύμπτυξη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="461"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Πάνω</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>16 px</source>
        <translation>16 εικ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>24 px</source>
        <translation>24 εικ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>32 px</source>
        <translation>32 εικ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>48 px</source>
        <translation>48 εικ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>All files (*)</source>
        <translation>Όλα τα αρχεία (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Add only if &amp;newer</source>
        <translation>Προσθήκη μόνο αν είναι &amp;νεώτερο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Confirm</source>
        <translation>Επιβεβαίωση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Είστε σίγουρος-η ότι θέλετε να διαγράψετε τα επιλεγμένα αρχεία;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Version: %1</source>
        <translation>Έκδοση: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>%p %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>Success</source>
        <translation>Επιτυχία</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>No errors have been found.</source>
        <translation>Δεν βρέθηκαν σφάλματα.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="912"/>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>N/A</source>
        <translation>Μ/Δ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1001"/>
        <source>Uncompressed Size:</source>
        <translation>Αποσυμπιεσμένο μέγεθος:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>Compression Ratio:</source>
        <translation>Λόγος συμπίεσης:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1058"/>
        <source>File name</source>
        <translation>Όνομα αρχείου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1059"/>
        <source>File Type</source>
        <translation>Τύπος αρχείου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1060"/>
        <source>File Size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1061"/>
        <source>Modified</source>
        <translation>Τροποποιήθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1062"/>
        <source>Encrypted</source>
        <translation>Κρυπτογραφημένο</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1088"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n αρχείο</numerusform>
            <numerusform>%n αρχεία</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Κρυπτογράφηση του κατάστιχου αρχείων</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Εμφάνιση κωδικού πρόσβασης</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Κωδικός πρόσβασης:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Σημείωση:&lt;/b&gt; ο κωδικός πρόσβασης θα χρησιμοποιηθεί για την κρυπτογράφηση των αρχείων που προσθέτετε στην τρέχουσα αρχειοθήκη, και για την αποκρυπτογράφηση των αρχείων που εξάγετε από την τρέχουσα αρχειοθήκη. Κατά το κλείσιμο της αρχειοθήκης ο κωδικός πρόσβασης διαγράφεται.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Πρόοδος</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="298"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar συμπιεσμένο με 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar συμπιεσμένο με bzip2 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar συμπιεσμένο με bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Rar αρχειοθήκη βιβλίου κόμικ (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Zip αρχειοθήκη βιβλίου κόμικ (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar συμπιεσμένο με gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Αυτοαποσυμπιεζόμενο zip (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar συμπιεσμένο με lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar συμπιεσμένο με lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar συμπιεσμένο με lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar συμπιεσμένο με lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>Μορφή Windows Imaging (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Μη συμπιεσμένη αρχειοθήκη (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar συμπιεσμένο με compress (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar συμπιεσμένο με xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar συμπιεσμένο με zstd (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>Προσθήκη του αρχείου: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="280"/>
        <source>Extracting file: </source>
        <translation>Εξαγωγή του αρχείου: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>Αφαίρεση του αρχείου: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>Διαγραφή των αρχείων από την αρχειοθήκη</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>Επανασυμπίεση της αρχειοθήκης</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>Αποσυμπίεση της αρχειοθήκης</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Το αρχείο δε βρέθηκε.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Ο τύπος της αρχειοθήκης δεν υποστηρίζεται.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Η αρχειοθήκη δεν βρέθηκε</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Δεν έχετε τις κατάλληλες άδειες.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Ο τύπος της αρχειοθήκης δεν μπορεί να τροποποιηθεί</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Δεν μπορείτε να προσθέσετε μια αρχειοθήκη στον εαυτό της.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Αδύνατη η εύρεση του τόμου: %s</translation>
    </message>
</context>
</TS>
